@@ -12,6 +12,9 @@ class SuperClass(object):
     def some_finalized_method(self):
         return "super_final"
 
+    @final
+    class SomeFinalClass:
+        pass
 
 class SubClass(SuperClass):
     @overrides
@@ -63,6 +66,18 @@ class FinalTests(unittest.TestCase):
         except TypeError:
             pass
 
+    def test_final_fails_inner_class(self):
+        try:
+
+            class SubClassFail(SuperClass):
+                @overrides
+                class SomeFinalClass:
+                    pass
+
+            raise RuntimeError("Should not go here")
+        except TypeError:
+            pass
+
     def test_final_fails_another_package(self):
         try:
 
