@@ -1,13 +1,19 @@
+import sys
 import unittest
-from overrides import overrides
-import test_somepackage
-
-
+from contextlib import contextmanager
 from typing import Generic, TypeVar
 
+import test_somepackage
+from overrides import overrides
+
 TObject = TypeVar("TObject", bound="Foo")
 
 
+@contextmanager
+def no_error():
+    yield
+
+
 class SubClassOfGeneric(Generic[TObject]):
     def some_method(self):
         """Generic sub class."""
@@ -29,6 +35,10 @@ class SuperClass(object):
         """Super Class Docs"""
         return "super"
 
+    class SomeClass:
+        """Super Inner Class Docs"""
+        def check(self):
+            return 0
 
 class SubClass(SuperClass):
     @overrides
@@ -72,12 +82,25 @@ class StaticMethodOverridePass(SuperClass):
         pass
 
 
+class InnerClassOverride(SuperClass):
+    @overrides
+    class SomeClass:
+        def check(self):
+            return 1
+
 class OverridesTests(unittest.TestCase):
     def test_overrides_passes_for_same_package_superclass(self):
         sub = SubClass()
         self.assertEqual(sub.some_method(), "sub")
         self.assertEqual(sub.some_method.__doc__, "Super Class Docs")
 
+    def test_override_inner_class(self):
+        sup = SuperClass.SomeClass()
+        sub = InnerClassOverride.SomeClass()
+        self.assertEqual(sup.check(), 0)
+        self.assertEqual(sub.check(), 1)
+        self.assertEqual(sup.__doc__, sub.__doc__)
+
     def test_overrides_does_not_override_method_doc(self):
         sub = Subber()
         self.assertEqual(sub.some_method(), 1)
@@ -126,6 +149,29 @@ class OverridesTests(unittest.TestCase):
         with self.assertRaises(TypeError):
             CheckAtRuntime().some_method(1)
 
+    def test_overrides_builtin_method_correct_signature(self):
+        class SubclassOfInt(int):
+            @overrides
+            def bit_length(self):
+                return super().bit_length()
+
+        x = SubclassOfInt(1)
+        self.assertEqual(x.bit_length(), 1)
+
+    def test_overrides_builtin_method_incorrect_signature(self):
+        if sys.version_info >= (3, 7):
+            expected_error = self.assertRaises(TypeError)
+        else:
+            # In 3.6 inspecting signature's isn't possible for builtin
+            # methods so this this passes the signature check.
+            expected_error = no_error()
+
+        with expected_error:
+            class SubclassOfInt(int):
+                @overrides
+                def bit_length(self, _):
+                    "This will fail, bit_length takes in no arguments"
+
 
 if __name__ == "__main__":
     unittest.main()
