@@ -1,4 +1,4 @@
-from typing import Type, Union
+from typing import Any, Type, Union
 
 from overrides import overrides
 
@@ -82,6 +82,24 @@ class B(A):
         pass
 
 
+class UntypedBaseClass:
+    def do_something(self, arg1, arg2=None):
+        pass
+
+
+def test_typed_subclass_in_same_package_is_an_error():
+    try:
+
+        class TypedSubclass(UntypedBaseClass):
+            @overrides
+            def do_something(self, arg1: str, arg2: Any = None) -> Any:
+                pass
+
+        raise AssertionError("Should not go here")
+    except TypeError:
+        pass
+
+
 def test_that_this_file_is_ok():
     pass
 
